%define api 1.0
%define major 0
%define libname %mklibname usb %{api} %{major}
%define devellibname %mklibname -d usb %{api}
%define fversion 1.0.27
#define pre rc3
%define fpre %{?pre:-%{pre}}

Summary:	Library for accessing USB devices
Name:		libusb
Version:	%{fversion}%{?pre:~%{pre}}
Release:	%mkrel 1

Source0:	https://github.com/libusb/libusb/releases/download/v%{fversion}/libusb-%{fversion}%{fpre}.tar.bz2
License:	LGPLv2+
Group:		System/Libraries
URL:		https://libusb.info/

BuildRequires:	doxygen
BuildRequires:	pkgconfig(udev)

%description
This package provides a way for applications to access USB devices.

Libusb is a C library that gives applications easy access to USB devices on
many different operating systems.

Note that this library is not compatible with the original libusb-0.1 series,
if you need libusb-0.1 compatibility install the libusb-compat package.


%package -n	%{libname}
Summary:	%{summary}
Group:		System/Libraries
Requires(pre):	filesystem >= 2.1.9-18
Obsoletes:	%{_lib}usbx1.0_0 < 1.0.13

%description -n	%{libname}
This package provides a way for applications to access USB devices.

Libusb is a C library that gives applications easy access to USB devices on
many different operating systems.

Note that this library is not compatible with the original libusb-0.1 series,
if you need libusb-0.1 compatibility install the libusb-compat package.


%package -n	%{devellibname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:	libusb1-devel = %{version}
Provides:	libusbx-devel = %{version}
Provides:	%{name}-devel = %{version}
Provides:	usb1-devel = %{version}
Provides:	usb1.0-devel = %{version}
Obsoletes:	%{_lib}usb1.0-static-devel <= 1.0.9
Obsoletes:	%{_lib}usbx1.0-devel < 1.0.13
Requires(pre):	filesystem >= 2.1.9-18

%description -n	%{devellibname}
The %{devellibname} package contains libraries and header files for
developing applications that use %{name}.


%package	devel-doc
Summary:	Development documentation for %{name}
Group:		Development/C
BuildArch:	noarch
Requires:	pkgconfig(libusb-1.0) = %{fversion}
Provides:	libusbx-devel-doc

%description	devel-doc
This package contains API documentation for %{name}.


%package        tests-examples
Summary:        Tests and examples for %{name}
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description tests-examples
This package contains tests and examples for %{name}.


%prep
%autosetup -p1 -n %{name}-%{fversion}%{fpre}


%build
%configure --disable-static --enable-examples-build
%make_build

pushd doc
  doxygen -u doxygen.cfg
  make docs
popd

pushd tests
  make
popd


%install
%make_install

install -Dpm 755 examples/.libs/testlibusb \
    $RPM_BUILD_ROOT%{_bindir}/libusb-test-libusb

# Some examples are very device-specific / require specific hw and miss --help
# So we only install a subset of more generic / useful examples
for i in fxload listdevs xusb; do
    install -m 755 examples/.libs/$i \
        $RPM_BUILD_ROOT%{_bindir}/libusb-example-$i
done

%check
LD_LIBRARY_PATH=libusb/.libs $RPM_BUILD_ROOT%{_bindir}/libusb-test-libusb
LD_LIBRARY_PATH=libusb/.libs $RPM_BUILD_ROOT%{_bindir}/libusb-example-listdevs

%files -n %{libname}
%license COPYING
%doc AUTHORS README ChangeLog
%{_libdir}/libusb-%{api}.so.%{major}{,.*}

%files -n %{devellibname}
%{_libdir}/pkgconfig/libusb-%{api}.pc
%{_includedir}/libusb-%{api}
%{_libdir}/libusb-%{api}.so

%files devel-doc
%doc doc/api-1.0 examples/*.c

%files tests-examples
%{_bindir}/libusb-example-fxload
%{_bindir}/libusb-example-listdevs
%{_bindir}/libusb-example-xusb
%{_bindir}/libusb-test-libusb


%changelog
* Wed May 22 2024 wally <wally> 1.0.27-1.mga10
+ Revision: 2066195
- new version 1.0.27

* Thu May 25 2023 ghibo <ghibo> 1.0.26-1.mga9
+ Revision: 1957941
- Drop patches merged upstream
- Update to release 1.0.26

* Thu Mar 24 2022 umeabot <umeabot> 1.0.24-4.mga9
+ Revision: 1824439
- Mageia 9 Mass Rebuild

* Sun Mar 14 2021 luigiwalser <luigiwalser> 1.0.24-3.mga9
+ Revision: 1702655
- actually bump rel and rebuild to be higher than mga8

* Sun Feb 28 2021 tv <tv> 1.0.24-2.mga9
+ Revision: 1693268
- Pull in upstream bugfixes for iPhone detection (rhbz#1929148)

* Mon Dec 14 2020 tv <tv> 1.0.24-2.mga8
+ Revision: 1657027
- build & run tests
- parrallel build is fixed :-) !
- use %%license
- do not package useless NEWS

* Sun Dec 13 2020 tmb <tmb> 1.0.24-1.mga8
+ Revision: 1656547
- adjust to new html docs location
- update to 1.0.24

* Wed Apr 08 2020 luigiwalser <luigiwalser> 1.0.23-1.mga8
+ Revision: 1565484
- 1.0.23

* Fri Feb 14 2020 umeabot <umeabot> 1.0.22-2.mga8
+ Revision: 1521549
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Fri Dec 28 2018 luigiwalser <luigiwalser> 1.0.22-1.mga7
+ Revision: 1345817
- 1.0.22

* Sun Sep 23 2018 umeabot <umeabot> 1.0.21-2.mga7
+ Revision: 1299200
- Mageia 7 Mass Rebuild

* Thu Nov 03 2016 tv <tv> 1.0.21-1.mga6
+ Revision: 1064889
- new release
- fix source URL

* Fri Apr 15 2016 tv <tv> 1.0.20-3.mga6
+ Revision: 1001620
- provides libusbx-devel

* Thu Feb 11 2016 umeabot <umeabot> 1.0.20-2.mga6
+ Revision: 955715
- Mageia 6 Mass Rebuild

* Mon Sep 14 2015 tv <tv> 1.0.20-1.mga6
+ Revision: 879174
- new release

* Sun Sep 06 2015 tv <tv> 1.0.20~rc3-2.mga6
+ Revision: 873771
- make devel doc installable

* Sun Sep 06 2015 tv <tv> 1.0.20~rc3-1.mga6
+ Revision: 873331
- 1.0.20 RC3
  (parrallel build is broken)
- use "~" for RC

* Fri Aug 21 2015 tmb <tmb> 1.0.19-10.mga6
+ Revision: 867761
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.0.19-9.mga5
+ Revision: 741034
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.19-8.mga5
+ Revision: 681831
- Mageia 5 Mass Rebuild

* Sun Jul 20 2014 tv <tv> 1.0.19-7.mga5
+ Revision: 654652
- use pkgconfig requires
  doc-devel is noarch, it cannot requires a arched devel pkg, thus fixing
  requires on i586 (the broken one could randomly be x86_64 on next rebuild)

* Sat Jul 05 2014 tv <tv> 1.0.19-6.mga5
+ Revision: 643458
- restore a bogusly removed require

* Sat Jul 05 2014 tv <tv> 1.0.19-5.mga5
+ Revision: 643444
- fix doc package requires after previous change
-remove lisbusb-devel provides, we historically had lisbusb1-devel provides
 not %%name-devel provides which was wrongly added in commit 273679

* Sat Jul 05 2014 tv <tv> 1.0.19-4.mga5
+ Revision: 643435
- restore libusb-provides

* Sat Jul 05 2014 wally <wally> 1.0.19-3.mga5
+ Revision: 643408
- drop libusb-devel provide which is used in libusb-compat-devel pkg (fixes numerous autobuild failures)

* Tue Jun 17 2014 tv <tv> 1.0.19-2.mga5
+ Revision: 637847
- obsoletes libusbx-devel-doc

* Tue Jun 17 2014 tv <tv> 1.0.19-1.mga5
+ Revision: 637842
- new release
- libusbx has been renamed as libusb

* Tue Feb 04 2014 sander85 <sander85> 1.0.18-1.mga5
+ Revision: 580563
- New version: 1.0.18

* Sat Oct 19 2013 umeabot <umeabot> 1.0.17-2.mga4
+ Revision: 533836
- Mageia 4 Mass Rebuild

* Sat Sep 07 2013 luigiwalser <luigiwalser> 1.0.17-1.mga4
+ Revision: 475603
- update to final 1.0.17 release

* Wed Aug 28 2013 tv <tv> 1.0.17-0.rc1.1.mga4
+ Revision: 472598
- new release

* Fri Jul 12 2013 tv <tv> 1.0.16-1.mga4
+ Revision: 453560
- new release

* Tue Jul 09 2013 tv <tv> 1.0.16-0.rc3.1.mga4
+ Revision: 452264
- new release

* Tue Jul 02 2013 tv <tv> 1.0.16-0.rc2.1.mga4
+ Revision: 449819
- new release

* Thu Jun 20 2013 tv <tv> 1.0.16-0.rc1.1.mga4
+ Revision: 445301
- BR udev-devel
- BS's rpm does not support tilde (\~) in version tag yet
- new release

* Sun Jun 02 2013 sander85 <sander85> 1.0.15-1.mga4
+ Revision: 434445
- New version: 1.0.15

* Sat Jan 12 2013 umeabot <umeabot> 1.0.14-2.mga3
+ Revision: 358307
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 29 2012 fwang <fwang> 1.0.14-1.mga3
+ Revision: 299979
- new version 1.0.14

* Sat Sep 22 2012 fwang <fwang> 1.0.13-2.mga3
+ Revision: 296607
- obsoletes old packages

* Fri Sep 21 2012 fwang <fwang> 1.0.13-1.mga3
+ Revision: 296460
- new version 1.0.13
+ sander85 <sander85>
- Make doc package noarch

* Sun Jul 22 2012 cjw <cjw> 1.0.12-3.mga3
+ Revision: 273536
- revert some changes from previous release:
  o add libusb1-devel provides
  o documentation in libusbx-devel-doc
  o obsoletes on old -static-devel package

* Sun Jul 22 2012 cjw <cjw> 1.0.12-2.mga3
+ Revision: 273512
- drop doc package
- follow library policy
- backwards compatible devel provides, no new ones
+ sander85 <sander85>
- Update URL
- fix libusb-compat's name in description

* Sun Jul 22 2012 sander85 <sander85> 1.0.12-1.mga3
+ Revision: 273400
- imported package libusbx

